import React, {Component} from 'react';
import {PropTypes} from 'prop-types';
import "./../../core/styles/tipography.css";
import "../../core/styles/buttons.scss";
import "./../../core/styles/inputs.css";
import "./style.scss";

export class List extends Component {

	constructor(props){
		super(props);
		this.state = {
			items: [].concat(this.props.initialItems),
			newItem: ""
		};
		this._onNewItemTextChange = this._onNewItemTextChange.bind(this);
		this._save = this._save.bind(this);
	}

	_renderItem(item, index) {

		return (<li className="list-items__item" key={index}>{item}</li>);
	}

	_onNewItemTextChange(e){

		const newItem = e.target.value;
		this.setState({
			newItem
		})
	}

	_save(){

		const items = [].concat(this.state.items);
		if(this.state.newItem && this.state.newItem.toString().length){
			items.push(this.state.newItem.toString());
			this.setState({
				items: items,
				err: ""
			}, () => {
				this.props.onItemsChange && this.props.onItemsChange([].concat(this.state.items));
				//console.log(`state updated: ${JSON.stringify(this.state)}`);
			})
		}else{
			this.setState({
				err: "Element must have a value"
			}, () => {
				//console.log(`state updated: ${JSON.stringify(this.state)}`);
			})
		}

	}

	render() {

		let items = [].concat(this.state.items);
		if(this.props.maxItems){
			items = items.slice(0, this.props.maxItems);
		}
		//console.log(`this.state.items: ${JSON.stringify(this.state.items)}`);
		//console.log(`this.props.maxItems: ${this.props.maxItems}`);
		//console.log(`items: ${JSON.stringify(items)}`);
		return(<div className={`list list-${this.props.theme} list-${this.props.orientation} ${this.state.err ? "list-error" : ""}\``}>
			{(this.props.title || this.props.showCount) && <div className="list-title">
				{this.props.title}
				{this.props.showCount && <span> ({items.length})</span>}
			</div>}
			{(!items || items.length === 0)&& <p className="list-message">
				{this.props.noItemsMessage}
			</p>}
			{items && items.length > 0 && <ul className="list-items">
				{items.map(this._renderItem)}
			</ul>}
			{this.props.toolbar && <div className="list-toolbar">
				<input className="list-toolbar__text" type="text" onChange={this._onNewItemTextChange} value={this.state.newItem}/>
				<button className={`list-toolbar__add button button button-${this.props.theme}`} onClick={this._save}>Add</button>
				&nbsp;<span className="list-toolbar__validation">{this.state.err}</span>
			</div>}
		</div>);
	}
}

List.propTypes = {
	initialItems: PropTypes.arrayOf(PropTypes.string),
	noItemsMessage: PropTypes.string,
	title: PropTypes.string,
	showCount: PropTypes.bool,
	maxItems: PropTypes.number,
	theme: PropTypes.oneOf(['marketplace', 'warehouse', 'admin', 'default']),
	orientation: PropTypes.oneOf(['vertical', 'horizontal']),
	toolbar: PropTypes.bool,
	onItemsChange: PropTypes.func
};

List.defaultProps = {
	initialItems: [],
	noItemsMessage: "Sorry, there are no items available",
	title: "List",
	showCount: true,
	theme: "default",
	orientation: 'vertical',
	toolbar: false
};
export default List;
